import React, { FC } from 'react';
import { TextField } from '@material-ui/core';
import { Control, Controller, FieldValues } from 'react-hook-form';

type Props = {
  /**
   * Name of the elemement. (ex. email, password).
   */
  name: string;
  /**
   * Aria label.
   */
  label: string;
  /**
   * Takes error from react-hook-form and is thrown if
   * the component is not valid.
   */
  error?: boolean;
  /**
   * Message to display if the component is not valid.
   */
  errorMessage?: string;
  /**
   * React-hook-form control.
   */
  control: Control<FieldValues> | undefined;
  /**
   * Validation rules.
   */
  rules?: Partial<unknown>;
  /**
   * HTML type of input.
   */
  type: string;

  /**
   * MUI props override for defining style on fly.
   */
  InputLabelProps?: Record<string, boolean>;
};

export const InputField: FC<Props> = (props: Props) => {
  const {
    name,
    label,
    error,
    type,
    errorMessage,
    control,
    rules,
    InputLabelProps,
  } = props;
  return (
    <Controller
      name={name}
      control={control}
      rules={rules}
      render={({ onChange, value }) => (
        <TextField
          variant="outlined"
          margin="normal"
          type={type}
          required
          fullWidth
          id={name}
          label={label}
          name={name}
          onChange={onChange}
          value={value}
          autoComplete={name}
          autoFocus
          error={error}
          helperText={error && errorMessage}
          InputLabelProps={{ ...InputLabelProps, shrink: true }}
        />
      )}
    />
  );
};

InputField.defaultProps = {
  rules: undefined,
  error: false,
  errorMessage: '',
  InputLabelProps: {},
};
