import { fetchCookie } from 'api/fetchCookie';
import { useCallback, useEffect, useState } from 'react';

/**
 * Custom hook that return csrf cookie fetched from server.
 *
 * @return cookie
 */
export const useCookie = (): string => {
  const [cookie, setCookie] = useState('');

  const askCookie = useCallback(() => {
    let isMounted = true;
    if (isMounted)
      fetchCookie().then((cookieResponse) => setCookie(cookieResponse));

    return () => {
      isMounted = false;
    };
  }, []);

  useEffect(() => {
    askCookie();
  }, [askCookie]);

  return cookie;
};
